@@ -18,15 +18,31 @@ from sanic_ext.extensions.openapi.builders import SpecificationBuilder
 from sanic_ext.extensions.openapi.extension import OpenAPIExtension
 from sanic_ext.utils.string import camel_to_snake
 
+try:
+    from jinja2 import Environment
+
+    from sanic_ext.extensions.templating.engine import Templating
+    from sanic_ext.extensions.templating.extension import TemplatingExtension
+
+    TEMPLATING_ENABLED = True
+except (ImportError, ModuleNotFoundError):
+    TEMPLATING_ENABLED = False
+
 MIN_SUPPORT = (21, 3, 2)
 
 
 class Extend:
+    _pre_registry: List[Union[Type[Extension], Extension]] = []
+
+    if TEMPLATING_ENABLED:
+        environment: Environment
+        templating: Templating
+
     def __init__(
         self,
         app: Sanic,
         *,
-        extensions: Optional[List[Type[Extension]]] = None,
+        extensions: Optional[List[Union[Type[Extension], Extension]]] = None,
         built_in_extensions: bool = True,
         config: Optional[Union[Config, Dict[str, Any]]] = None,
         **kwargs,
@@ -65,6 +81,7 @@ class Extend:
         self.config = add_fallback_config(app, config, **kwargs)
 
         extensions = extensions or []
+        extensions.extend(Extend._pre_registry)
         if built_in_extensions:
             extensions.extend(
                 [
@@ -74,19 +91,24 @@ class Extend:
                 ]
             )
 
+            if TEMPLATING_ENABLED:
+                extensions.append(TemplatingExtension)
+
         started = set()
-        for extclass in extensions[::-1]:
-            if extclass in started:
+        for ext in extensions[::-1]:
+            if ext in started:
                 continue
-            extension = extclass(app, self.config)
+            extension = Extension.create(ext, app, self.config)
             extension._startup(self)
             self.extensions.append(extension)
-            started.add(extclass)
+            started.add(ext)
 
     def _display(self):
         init_logs = ["Sanic Extensions:"]
         for extension in self.extensions:
-            init_logs.append(f"  > {extension.name} {extension.label()}")
+            init_logs.append(
+                f"  > {extension.name} {extension.render_label()}"
+            )
 
         list(map(logger.info, init_logs))
 
@@ -127,3 +149,14 @@ class Extend:
             self._openapi = SpecificationBuilder()
 
         return self._openapi
+
+    def template(self, template_name: str, **kwargs):
+        return self.templating.template(template_name, **kwargs)
+
+    @classmethod
+    def register(cls, extension: Union[Type[Extension], Extension]) -> None:
+        cls._pre_registry.append(extension)
+
+    @classmethod
+    def reset(cls) -> None:
+        cls._pre_registry.clear()
